==> korweblog-1.5.8.tar.gz: korweblog-1.5.8/priv_msg.php <==
<?
/*--------------------------------------------------------------------
   KorWeblog :: Highly Customizable Weblog/CMS
   Copyright (C) 2001,2002 by Im Eunjea <eunjea@kldp.org>
   For detail of license and/or other info, see the file doc/COPYING.
   http://weblog.kldp.org
----------------------------------------------------------------------

LICENSE

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software 
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
----------------------------------------------------------------------*/

include("include/common.inc.php");
if (!$login) KWL_Redirect("login.php");
$priv_msg_limit = 2048 * 100;
$PRIV['Heading'] = _PRIV_MSG;
settype($what, "string");
switch ($what) {
	case "send":
      list($title,$text,$name,$faceicon,$from_userid) = KWL_UserVars(array('title','text','name','faceicon','from_userid'),'trim');
		$title = trim($title);
		$text = trim($text);
		if (empty($title) || empty($text)) KWL_ShowError(_NO_INPUT);
		if (strlen($text) > $priv_msg_limit) KWL_ShowError(_TOO_BIG);
		$recip = KWL_GetUserInfo("name","$name");
		if (!$recip) KWL_ShowError(_NO_USER);
		if (!in_array($faceicon, KWL_GetFileName("$CONF[G_PATH]/images.d/face")))
         $faceicon = "";

		/* check if it's same msg */
		$lst_txt = SqlResult("SELECT msg_text FROM T_Priv_msgs WHERE to_userid = '$recip[uid]' AND from_userid = '$from_userid' ORDER BY msg_id DESC LIMIT 0,1");
		if ($lst_txt == $text) KWL_ShowError(_SAME_MSG);

		/* check if recip's msg box is full */
		if ($CONF['Priv_msg_limit'] <= SqlCount("T_Priv_msgs","to_userid",$recip['uid'])) KWL_ShowError(_RECEIP_BOX_FULL);

		$sql = "INSERT INTO T_Priv_msgs VALUES ('', '$faceicon', '$title', '$from_userid', '$recip[uid]', '". time() ."', '$text', 0)";
		if (SqlQuery($sql)) $PRIV['Content'] = _MSG_SENDED . "<P>";
		$PRIV['Content'] .= "[ <A HREF=\"priv_msg.php?what=list\">". _LIST ."</A> ]</CENTER>";
	break;

	case "delete":
		$sql = "DELETE FROM T_Priv_msgs WHERE msg_id = '$msg_id'";
		$PRIV['Content'] = "<CENTER>";
		if (SqlQuery($sql)) $PRIV['Content'] .= _MSG_DELETED . "<P>";
		$PRIV['Content'] .= "[ <A HREF=\"priv_msg.php?what=list\">". _LIST ."</A> ]</CENTER>";
	break;

	case "read":
		$sql = "SELECT * FROM T_Priv_msgs WHERE msg_id = '$msg_id'";
		$A = SqlQueryFetchArray($sql);
		$from_user = KWL_GetUserInfo("uid",$A['from_userid']);
		if (!empty($A['msg_image'])) $face = "<IMG SRC=\"$CONF[G_URL]/images.d/face/$A[msg_image]\" BORDER=\"0\" VSPACE=\"0\" HSPACE=\"0\" ALT=\"\">";
		$PRIV['Content']  = "
		<TABLE WIDTH=\"100%\" BORDER=\"1\" CELLSPACING=\"0\" CELLPADDING=\"3\">
		<TR><TD>". _SENDER .": <A HREF=\"$CONF[G_URL]/profiles.php?uid=$A[from_userid]\">". htmlspecialchars($from_user['name']) ."</A></TD>
		<TR><TD>". _DATE .": ". KWL_strftime($A['msg_time'],"%Y-%b-%d %I:%M %p") ."</TD>
		<TR><TD>". _SUBJECT .": $face ". KWL_PrepareHtml($A['subject']) ."</TD>
		<TR><TD>". KWL_ParseContent($A['msg_text'],3) ."</TD>
		<TR><TD ALIGN=CENTER>[ <A HREF=\"priv_msg.php?what=reply&msg_id=$msg_id&from_userid=$A[from_userid]\">". _REPLY_MSG ."</A> | <A HREF=\"priv_msg.php?what=list\">". _LIST ."</A> | <A HREF=\"priv_msg.php?what=delete&msg_id=$msg_id\">". _DELETE ."</A> ]</TD></TR></TABLE>";
		SqlQuery("UPDATE T_Priv_msgs SET read_msg = 1 WHERE msg_id = '$msg_id'");
	break;

	case "write":
      settype($uid, "integer");
		$PRIV['Heading'] = _SEND_PRIV_MSG;
		$PRIV['Content'] = KWL_PrivMsgForm("write",$uid);
	break;

	case "reply":
		$PRIV['Heading'] = _SEND_PRIV_MSG;
		$PRIV['Content'] = KWL_PrivMsgForm("reply",$msg_id,$from_userid);
	break;

	default;
		$sql = "SELECT msg_id, msg_image, subject, from_userid, to_userid, msg_time, read_msg FROM T_Priv_msgs WHERE to_userid = '$user[uid]' ORDER BY msg_id DESC";
		$result = SqlQuery($sql);
		$PRIV['Content']  = "
		<TABLE WIDTH=\"100%\" BORDER=\"1\" CELLSPACING=\"0\" CELLPADDING=\"3\">
		<TR><TD COLSPAN=2 WIDTH=1%>&nbsp;</TD><TD>". _SENDER ."</TD><TD WIDTH=60%>". _SUBJECT ."</TD><TD>". _DATE ."</TD>";
		if (mysql_num_rows($result)) {
			while ($A = mysql_fetch_array($result)) {
			$from_user = KWL_GetUserInfo("uid",$A['from_userid']);
			if (!$A['read_msg']) $img = "<IMG SRC=\"$CONF[G_URL]/images.d/comment.gif\" HEIGHT=\"11\" WIDTH=\"14\">";
			else $img = "&nbsp;";
			if (!empty($A['msg_image'])) $face = "<IMG SRC=\"$CONF[G_URL]/images.d/face/$A[msg_image]\" BORDER=\"0\" VSPACE=\"0\" HSPACE=\"0\" ALT=\"\">";
			else $face = "&nbsp;";
			$PRIV['Content'] .= "<TR><TD ALIGN=CENTER>$img</TD><TD ALIGN=CENTER>$face</TD>
			<TD><A HREF=\"profiles.php?uid=$A[from_userid]\">". htmlspecialchars($from_user['name']) ."</A></TD>
			<TD><A HREF=\"priv_msg.php?what=read&msg_id=$A[msg_id]\">". htmlspecialchars($A['subject']) ."</A></TD>
			<TD>". KWL_strftime($A['msg_time'],"%b-%d %I:%M %p") ."</TD></TR>";
			}
		} else $PRIV['Content'] .= "<TR><TD COLSPAN=5 ALIGN=CENTER>". _NO_MSG ."</TD></TR>";
		$PRIV['Content'] .= "<TR><TD COLSPAN=5 ALIGN=CENTER>[ <A HREF=\"priv_msg.php?what=write\">". _SEND_PRIV_MSG ."</A> ]</TD></TR></TABLE>";
		$PRIV['Content'] .= "<FONT SIZE=\"-1\">". sprintf(_PRIVMSG_MAX,$CONF['Priv_msg_limit']) ."</FONT>";
}

$head = _PRIV_MSG;
include("include/header.inc.php");
KWL_UserNavig();
KWL_DrawMain($PRIV);
include("include/footer.inc.php");

function KWL_PrivMsgForm($type,$data,$from_userid='') {
   global $agent, $size, $user;

   settype($data, "integer");
   settype($from_userid, "integer");
   if ($type == "write") {
      $recip = KWL_GetUserInfo("uid","$data");
      $A['subject'] = "";
   } else {
      $recip = KWL_GetUserInfo("uid","$from_userid");
      $sql = "SELECT * FROM T_Priv_msgs WHERE msg_id = '$data'";
      $A = SqlQueryFetchArray($sql);
      $A['subject'] = "Re: ". KWL_PrepareHtml(eregi_replace("re(\^[0-9])*: ", "", $A['subject']));
      $A['msg_text'] = KWL_QuoteText($A['msg_text'],$recip['name']);
   }
   
   $out = new KWL_Html;
   $ret = $out->form_start("priv_msg.php","Com").
          $out->table_start("100%",'',0,0,3).
          "<tr><td>" . _TO . ":</td><td>";
   if (empty($recip['name'])) $ret .= $out->input_form("text","name",'',$size['name'],60);
   else $ret .= "<a href=\"profiles.php?uid=$recip[uid]\">". KWL_PrepareHtml($recip['name']) ."</a>".
                $out->input_form("hidden","name",KWL_PrepareHtml($recip['name']));
   $ret .= "</td></tr><tr><td>" . _SUBJECT . ":</td><td>".
           $out->input_form("text","title",$A['subject'],$size['titl'],48).
           "</td></tr><tr><td>". _FACE .": </td><td>".
           $out->input_form("text","faceicon",'',KWL_FormSize(5),50).
           "<font size=\"-1\"><a href=\"viewimg.php?path=images.d/face&form=Com&var=faceicon\" target=\"_new\" onClick=\"new_windows('viewimg.php?path=images.d/face&form=Com&var=faceicon','viewicon',1,1,580,580); return false\">"._VIEW_FACE."</a></font></td></tr>".
           "<tr><td colspan=2>". KWL_FormResizer("Com.text",$size['text'],10) ."<BR>".
           $out->textarea("text",10,$size['text']). "</td></tr>".
           "<tr><td colspan=2>".
           $out->input_form("submit",'',_SEND);
   
   if ($type == "reply") {
      $ret .= $out->input_form("Hidden","hide","$A[msg_text]").
         "<input tabindex=\"100\" type=\"Button\" name=\"quote\" value=\""._QUOTE."\" onClick=\"this.form.text.value=this.form.text.value + this.form.hide.value; this.form.hide.value ='';\">";
   }
   $ret .= $out->input_form("hidden","from_userid",$user['uid']).
           $out->input_form("hidden","what","send").
           "[ <A HREF=\"priv_msg.php?what=list\">". _LIST ."</A> ]</TD></TR>".
           $out->table_end() . $out->form_end();
   return $ret;
}
?>

==> korweblog-1.6.0.tar.gz: korweblog-1.6.0/priv_msg.php <==
<?
/*--------------------------------------------------------------------
   KorWeblog :: Highly Customizable Weblog/CMS
   Copyright (C) 2001-2004 by Im Eunjea <eunjea@kldp.org>
   For detail of license and/or other info, see the file doc/COPYING.
   http://weblog.kldp.org
----------------------------------------------------------------------

LICENSE

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software 
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
----------------------------------------------------------------------*/

include("include/common.inc.php");
if (!$login) KWL_Redirect("login.php");
$priv_msg_limit = 2048 * 100;
$PRIV['Heading'] = _PRIV_MSG;
settype($what, "string");
switch ($what) {
	case "send":
      list($title,$text,$name,$faceicon,$from_userid) = KWL_UserVars(array('title','text','name','faceicon','from_userid'),'trim');
		$title = trim($title);
		$text = trim($text);
		if (empty($title) || empty($text)) KWL_ShowError(_NO_INPUT);
		if (strlen($text) > $priv_msg_limit) KWL_ShowError(_TOO_BIG);
		$recip = KWL_GetUserInfo("name","$name");
		if (!$recip) KWL_ShowError(_NO_USER);
		if (!in_array($faceicon, KWL_GetFileName("$CONF[G_PATH]/images.d/face")))
         $faceicon = "";

		/* check if it's same msg */
		$lst_txt = SqlResult("SELECT msg_text FROM T_Priv_msgs WHERE to_userid = '$recip[uid]' AND from_userid = '$from_userid' ORDER BY msg_id DESC LIMIT 0,1");
		if ($lst_txt == $text) KWL_ShowError(_SAME_MSG);

		/* check if recip's msg box is full */
		if ($CONF['Priv_msg_limit'] <= SqlCount("T_Priv_msgs","to_userid",$recip['uid'])) KWL_ShowError(_RECEIP_BOX_FULL);

		$sql = "INSERT INTO T_Priv_msgs VALUES ('', '$faceicon', '$title', '$from_userid', '$recip[uid]', '". time() ."', '$text', 0)";
		if (SqlQuery($sql)) $PRIV['Content'] = _MSG_SENDED . "<p />";
		$PRIV['Content'] .= "[ <a href=\"priv_msg.php?what=list\">". _LIST ."</a> ]</center>";
	break;

	case "delete":
		$sql = "DELETE FROM T_Priv_msgs WHERE msg_id = '$msg_id'";
		$PRIV['Content'] = "<center>";
		if (SqlQuery($sql)) $PRIV['Content'] .= _MSG_DELETED . "<p />";
		$PRIV['Content'] .= "[ <a href=\"priv_msg.php?what=list\">". _LIST ."</a> ]</center>";
	break;

	case "read":
		$sql = "SELECT * FROM T_Priv_msgs WHERE msg_id = '$msg_id'";
		$A = SqlQueryFetchArray($sql);
		$from_user = KWL_GetUserInfo("uid",$A['from_userid']);
		if (!empty($A['msg_image'])) $face = "<img src=\"$CONF[G_URL]/images.d/face/$A[msg_image]\" border=\"0\" vspace=\"0\" hspace=\"0\" alt=\"\" />";
      else $face = "";
		$PRIV['Content']  = "
		<table width=\"100%\" border=\"1\" cellspacing=\"0\" cellpadding=\"3\">
		<tr><td>". _SENDER .": <a href=\"$CONF[G_URL]/profiles.php?uid=$A[from_userid]\">". htmlspecialchars($from_user['name']) ."</a></td>
		<tr><td>". _DATE .": ". KWL_strftime($A['msg_time'],"%Y-%b-%d %I:%M %p") ."</td>
		<tr><td>". _SUBJECT .": $face ". KWL_PrepareHtml($A['subject']) ."</td>
		<tr><td>". KWL_ParseContent($A['msg_text'],3) ."</td>
		<tr><td align=\"center\">[ <a href=\"priv_msg.php?what=reply&amp;msg_id=$msg_id&amp;from_userid=$A[from_userid]\">". _REPLY_MSG ."</a> | <a href=\"priv_msg.php?what=list\">". _LIST ."</a> | <A HREF=\"priv_msg.php?what=delete&amp;msg_id=$msg_id\">". _DELETE ."</a> ]</td></tr></table>";
		SqlQuery("UPDATE T_Priv_msgs SET read_msg = 1 WHERE msg_id = '$msg_id'");
	break;

	case "write":
      settype($uid, "integer");
		$PRIV['Heading'] = _SEND_PRIV_MSG;
		$PRIV['Content'] = KWL_PrivMsgForm("write",$uid);
	break;

	case "reply":
		$PRIV['Heading'] = _SEND_PRIV_MSG;
		$PRIV['Content'] = KWL_PrivMsgForm("reply",$msg_id,$from_userid);
	break;

	default;
		$sql = "SELECT msg_id, msg_image, subject, from_userid, to_userid, msg_time, read_msg FROM T_Priv_msgs WHERE to_userid = '$user[uid]' ORDER BY msg_id DESC";
		$result = SqlQuery($sql);
		$PRIV['Content']  = "
		<table width=\"100%\" border=\"1\" cellspacing=\"0\" cellpadding=\"3\">
		<tr><td colspan=\"2\" width=\"1%\">&nbsp;</td><td>". _SENDER ."</td><td width=\"60%\">". _SUBJECT ."</td><td>". _DATE ."</td>";
		if (mysql_num_rows($result)) {
			while ($A = mysql_fetch_array($result)) {
			$from_user = KWL_GetUserInfo("uid",$A['from_userid']);
			if (!$A['read_msg']) $img = "<img src=\"$CONF[G_URL]/images.d/comment.gif\" height=\"11\" width=\"14\" />";
			else $img = "&nbsp;";
			if (!empty($A['msg_image'])) $face = "<img src=\"$CONF[G_URL]/images.d/face/$A[msg_image]\" border=\"0\" vspace=\"0\" hspace=\"0\" alt=\"\">";
			else $face = "&nbsp;";
			$PRIV['Content'] .= "<tr><td align=\"center\">$img</td><td align=\"center\">$face</td>
			<td><a href=\"profiles.php?uid=$A[from_userid]\">". htmlspecialchars($from_user['name']) ."</a></td>
			<td><a href=\"priv_msg.php?what=read&amp;msg_id=$A[msg_id]\">". htmlspecialchars($A['subject']) ."</a></td>
			<td>". KWL_strftime($A['msg_time'],"%b-%d %I:%M %p") ."</td></tr>";
			}
		} else $PRIV['Content'] .= "<tr><td colspan=\"5\" align=\"center\">". _NO_MSG ."</td></tr>";
		$PRIV['Content'] .= "<tr><td colspan=\"5\" align=\"center\">[ <a href=\"priv_msg.php?what=write\">". _SEND_PRIV_MSG ."</a> ]</td></tr></table>";
		$PRIV['Content'] .= sprintf(_PRIVMSG_MAX,$CONF['Priv_msg_limit']);
}

$head = _PRIV_MSG;
include("include/header.inc.php");
KWL_UserNavig();
KWL_DrawMain($PRIV);
include("include/footer.inc.php");

function KWL_PrivMsgForm($type,$data,$from_userid='') {
   global $agent, $size, $user;

   settype($data, "integer");
   settype($from_userid, "integer");
   if ($type == "write") {
      $recip = KWL_GetUserInfo("uid","$data");
      $A['subject'] = "";
   } else {
      $recip = KWL_GetUserInfo("uid","$from_userid");
      $sql = "SELECT * FROM T_Priv_msgs WHERE msg_id = '$data'";
      $A = SqlQueryFetchArray($sql);
      $A['subject'] = "Re: ". KWL_PrepareHtml(eregi_replace("re(\^[0-9])*: ", "", $A['subject']));
      $A['msg_text'] = KWL_QuoteText($A['msg_text'],$recip['name']);
   }
   
   $out = new KWL_Html;
   $ret = $out->form_start("priv_msg.php","Com").
          $out->table_start("100%",'',0,0,3).
          "<tr><td>" . _TO . ":</td><td>";
   if (empty($recip['name'])) $ret .= $out->input_form("text","name",'',$size['name'],60);
   else $ret .= "<a href=\"profiles.php?uid=$recip[uid]\">". KWL_PrepareHtml($recip['name']) ."</a>".
                $out->input_form("hidden","name",KWL_PrepareHtml($recip['name']));
   $ret .= "</td></tr><tr><td>" . _SUBJECT . ":</td><td>".
           $out->input_form("text","title",$A['subject'],$size['titl'],48).
           "</td></tr><tr><td>". _FACE .": </td><td>".
           $out->input_form("text","faceicon",'',KWL_FormSize(5),50).
           "<a href=\"viewimg.php?path=images.d/face&form=Com&var=faceicon\" target=\"_new\" onClick=\"new_windows('viewimg.php?path=images.d/face&form=Com&var=faceicon','viewicon',1,1,350,380); return false\">"._VIEW_FACE."</a></td></tr>".
           "<tr><td colspan=\"2\">". KWL_FormResizer("Com.text",$size['text'],10) ."<br />".
           $out->textarea("text",10,$size['text']). "</td></tr>".
           "<tr><td colspan=\"2\">".
           $out->input_form("submit",'',_SEND);
   
   if ($type == "reply") {
      $ret .= $out->input_form("Hidden","hide","$A[msg_text]").
         "<input tabindex=\"100\" type=\"Button\" name=\"quote\" value=\""._QUOTE."\" onClick=\"this.form.text.value=this.form.text.value + this.form.hide.value; this.form.hide.value ='';\">";
   }
   $ret .= $out->input_form("hidden","from_userid",$user['uid']).
           $out->input_form("hidden","what","send").
           "[ <a href=\"priv_msg.php?what=list\">". _LIST ."</a> ]</td></tr>".
           $out->table_end() . $out->form_end();
   return $ret;
}
?>
